import { type Writable } from 'svelte/store';
type OptionBase = {
    id: string;
    label: string;
    active: boolean;
    parent: OptionMenu | null;
    data?: Record<string, any>;
};
export type OptionSelect = OptionBase & {
    type: 'select';
    selected: boolean;
    isMulti: boolean;
};
export type InputSelectOption = Partial<Omit<OptionSelect, 'label'>> & Pick<OptionSelect, 'label'>;
export type OptionMenu = OptionBase & {
    type: 'menu';
    hasSelected: boolean;
    subOptions: OptionItem[];
};
export type InputMenuOption = Partial<Omit<OptionMenu, 'label' | 'subOptions'>> & Pick<OptionMenu, 'label'> & {
    subOptions: InputOptionItem[];
};
export type CloseOnSelect = 'never' | 'always' | 'not_multi';
export type Addition = {
    id: string;
    label: string;
};
export type SelectConfig = {
    closeOnSelect: CloseOnSelect;
    minSearchLength: number;
    additions: Addition[];
};
export type AddOption = {
    id: string;
    searchText: string;
};
export type OptionItem = OptionSelect | OptionMenu;
export type InputOptionItem = InputMenuOption | InputSelectOption;
export declare class Select {
    input: Writable<InputOptionItem[]>;
    config: SelectConfig;
    readonly events: {
        onSelect: Writable<OptionSelect>;
        onAdd: Writable<AddOption>;
    };
    readonly state: {
        isOpen: Writable<boolean>;
        selected: Writable<OptionSelect[]>;
        search: Writable<string>;
        options: Writable<OptionItem[]>;
        filteredOptions: Writable<OptionItem[]>;
        searchOptions: Writable<OptionSelect[]>;
        additionOptions: Writable<OptionSelect[]>;
    };
    constructor(inputOptions: InputOptionItem[], inputConfig?: Partial<SelectConfig>);
    open(): void;
    close(): void;
    toggleIsOpen(): void;
    selectOption(id: string): OptionSelect | null;
    addOption(id: string): null | undefined;
    getMenuOptions(): OptionMenu[];
    getOption(id: string): OptionItem | null;
    getSelectOption(id: string): OptionSelect | null;
    getActiveLeaf(): OptionItem | null;
    getActiveList(): OptionItem[];
    setActive(setOption: OptionItem | null): void;
    setPrevActive(): void;
    setNextActive(): void;
    setParentActive(): void;
    setChildActive(): void;
    private onSearchChange;
    private isSearchOptionId;
    private updateFilteredOptions;
    private updateSearchOptions;
    static toFlat(options: OptionItem[]): OptionItem[];
    static getParentLabels(option: OptionItem): string[];
    static toFlatSelect(options: OptionItem[]): OptionSelect[];
    private getSiblings;
    private setFirstActive;
    private getAllOptions;
    private getShowingSearchOptions;
    private static toSearchOption;
    private shouldClose;
    static inputToOptionItem(input: InputOptionItem, parent?: OptionItem): OptionItem;
    private updateAddableOption;
    onKeyDown(event: KeyboardEvent): void;
    onKeyUp(event: KeyboardEvent): void;
}
export declare function filterText(option: OptionItem, input?: string): boolean;
export {};
